@@ -382,16 +382,16 @@ class SOFPDFExtractor:
     def __init__(self, pdf):
         self.pdf = pdf
 
-    def createListFromPdf(self, pdf):
-        content = []
+    def createTextFromPdf(self, pdf):
+        content = ""
         with pdfplumber.open(pdf) as pdf:
             for page in pdf.pages:
-                content += page.extract_text().split("\n")
+                content += page.extract_text()
         
         return content
 
     def extract(self):
-        return self.createListFromPdf(self.pdf)
+        return self.createTextFromPdf(self.pdf)
 
 
 
